@@ -2,18 +2,19 @@
 
 set -e
 
-host="packages.netdata.cloud"
 user="netdatabot"
 
-distro="${1}"
-arch="${2}"
-format="${3}"
-repo="${4}"
+host="${1}"
+distro="${2}"
+arch="${3}"
+format="${4}"
+repo="${5}"
+pkg_src="${6:-./artifacts}"
 
 staging="${TMPDIR:-/tmp}/package-staging"
 prefix="/home/netdatabot/incoming/${repo}/"
 
-packages="$(find artifacts -name "*.${format}")"
+packages="$(find "${pkg_src}" -name "*.${format}")"
 
 mkdir -p "${staging}"
 
