@@ -5,15 +5,9 @@
 set -e
 
 declare -a package_tree=(
-  autoconf
-  autoconf-archive
-  automake
-  bison
   cmake
-  cmake3
   curl
   elfutils-libelf-devel
-  flex
   findutils
   gcc
   gcc-c++
@@ -22,7 +16,6 @@ declare -a package_tree=(
   json-c-devel
   libatomic
   libmnl-devel
-  libtool
   libuuid-devel
   libuv-devel
   libyaml-devel
