@@ -8,14 +8,8 @@ NON_INTERACTIVE=0
 DONT_WAIT=0
 
 package_tree="
-  autoconf
-  autoconf-archive
-  autogen
-  automake
-  bison
   cmake
   curl
-  flex
   g++
   gcc
   git
@@ -27,12 +21,10 @@ package_tree="
   libmnl-dev
   libssl-dev
   libsystemd-dev
-  libtool
   libuv1-dev
   libyaml-dev
   make
   pkg-config
-  python
   python3
   tar
   uuid-dev
