@@ -8,32 +8,26 @@ NON_INTERACTIVE=0
 DONT_WAIT=0
 
 package_tree="
+  app-alternatives/gzip
+  app-alternatives/tar
+  app-arch/lz4
+  dev-lang/python
+  dev-libs/json-c
+  dev-libs/libuv
+  dev-libs/libyaml
+  dev-libs/openssl
+  dev-util/cmake
   dev-vcs/git
+  net-libs/libmnl
+  net-misc/curl
   sys-apps/findutils
+  sys-apps/util-linux
   sys-devel/gcc
   sys-devel/make
-  sys-devel/autoconf
-  sys-devel/autoconf-archive
-  sys-devel/autogen
-  sys-devel/automake
-  virtual/pkgconfig
-  dev-util/cmake
-  app-arch/tar
-  net-misc/curl
-  app-arch/gzip
-  sys-apps/util-linux
-  net-libs/libmnl
-  dev-libs/json-c
-  dev-libs/libyaml
-  dev-libs/libuv
-  app-arch/lz4
-  dev-libs/openssl
   virtual/libelf
-  dev-lang/python
-  dev-libs/libuv
-  sys-devel/bison
-  sys-devel/flex
+  virtual/pkgconfig
   "
+
 usage() {
   cat << EOF
 OPTIONS:
