@@ -8,16 +8,10 @@ NON_INTERACTIVE=0
 DONT_WAIT=0
 
 declare -a package_tree=(
-  autoconf
-  autoconf-archive
-  autogen
-  automake
-  bison
   cmake
   curl
   elfutils-libelf-devel
   findutils
-  flex
   gcc
   gcc-c++
   git
@@ -25,7 +19,6 @@ declare -a package_tree=(
   json-c-devel
   libatomic
   libmnl-devel
-  libtool
   libuuid-devel
   libuv-devel
   libyaml-devel
