@@ -471,7 +471,7 @@ detect_package_manager_from_distribution() {
       package_installer="install_brew"
       tree="macos"
       if [ "${IGNORE_INSTALLED}" -eq 0 ] && [ -z "${brew}" ]; then
-        echo >&2 "command 'brew' is required to install packages on a '${distribution} ${version}' system."
+        echo >&2 "command 'brew' is required to install packages on a '${distribution} ${version}' system. Get instructions at https://brew.sh/"
         exit 1
       fi
       ;;
@@ -623,77 +623,21 @@ declare -A pkg_find=(
 
 declare -A pkg_distro_sdk=(
   ['alpine']="alpine-sdk"
+  ['centos']="kernel-headers"
   ['default']="NOTREQUIRED"
 )
 
-declare -A pkg_autoconf=(
-  ['gentoo']="sys-devel/autoconf"
-  ['clearlinux']="c-basic"
-  ['default']="autoconf"
+declare -A pkg_coreutils=(
+  ['alpine']="coreutils"
+  ['default']="NOTREQUIRED"
 )
 
-# required to compile netdata with --enable-sse
-# https://github.com/firehol/netdata/pull/450
-declare -A pkg_autoconf_archive=(
-  ['gentoo']="sys-devel/autoconf-archive"
-  ['clearlinux']="c-basic"
-  ['alpine']="WARNING|"
-  ['default']="autoconf-archive"
-
-  # exceptions
-  ['centos-6']="WARNING|"
-  ['rhel-6']="WARNING|"
-  ['rhel-7']="WARNING|"
-)
-
-declare -A pkg_autogen=(
-  ['gentoo']="sys-devel/autogen"
-  ['clearlinux']="c-basic"
-  ['alpine']="WARNING|"
-  ['default']="autogen"
-
-  # exceptions
-  ['centos-6']="WARNING|"
-  ['rhel-6']="WARNING|"
-  ['centos-9']="NOTREQUIRED|"
-  ['rhel-9']="NOTREQUIRED|"
-)
-
-declare -A pkg_automake=(
-  ['gentoo']="sys-devel/automake"
-  ['clearlinux']="c-basic"
-  ['default']="automake"
-)
-
-# Required to build libwebsockets and libmosquitto on some systems.
 declare -A pkg_cmake=(
   ['gentoo']="dev-util/cmake"
   ['clearlinux']="c-basic"
   ['default']="cmake"
 )
 
-# bison and flex are required by Fluent-Bit
-declare -A pkg_bison=(
-  ['default']="bison"
-)
-
-declare -A pkg_flex=(
-  ['default']="flex"
-)
-
-# fts-dev is required by Fluent-Bit on Alpine
-declare -A pkg_fts_dev=(
-  ['default']="NOTREQUIRED"
-  ['alpine']="musl-fts-dev" 
-  ['alpine-3.16.9']="fts-dev"
-)
-
-# cmake3 is required by Fluent-Bit on CentOS 7
-declare -A pkg_cmake3=(
-  ['default']="NOTREQUIRED"
-  ['centos-7']="cmake3"
-)
-
 declare -A pkg_json_c_dev=(
   ['alpine']="json-c-dev"
   ['arch']="json-c"
@@ -747,6 +691,11 @@ declare -A pkg_libsystemd_dev=(
   ['default']="systemd-devel"
 )
 
+declare -A pkg_pcre2=(
+  ['macos']="pcre2"
+  ['default']="NOTREQUIRED"
+)
+
 declare -A pkg_bridge_utils=(
   ['gentoo']="net-misc/bridge-utils"
   ['clearlinux']="network-basic"
@@ -761,13 +710,13 @@ declare -A pkg_curl=(
 )
 
 declare -A pkg_gzip=(
-  ['gentoo']="app-arch/gzip"
+  ['gentoo']="app-alternatives/gzip"
   ['macos']="NOTREQUIRED"
   ['default']="gzip"
 )
 
 declare -A pkg_tar=(
-  ['gentoo']="app-arch/tar"
+  ['gentoo']="app-alternatives/tar"
   ['clearlinux']="os-core-update"
   ['macos']="NOTREQUIRED"
   ['freebsd']="NOTREQUIRED"
@@ -946,7 +895,7 @@ declare -A pkg_postfix=(
 )
 
 declare -A pkg_pkg_config=(
-  ['alpine']="pkgconfig"
+  ['alpine']="pkgconf"
   ['arch']="pkgconfig"
   ['centos']="pkgconfig"
   ['debian']="pkg-config"
@@ -1228,6 +1177,7 @@ packages() {
   # basic build environment
 
   suitable_package distro-sdk
+  suitable_package coreutils
   suitable_package libatomic
 
   require_cmd git || suitable_package git
@@ -1237,14 +1187,9 @@ packages() {
     require_cmd gcc-multilib || suitable_package gcc
   require_cmd g++ || require_cmd clang++ || suitable_package gxx
 
-  require_cmd make || suitable_package make
-  require_cmd autoconf || suitable_package autoconf
-  suitable_package autoconf-archive
-  require_cmd autogen || suitable_package autogen
-  require_cmd automake || suitable_package automake
   require_cmd pkg-config || suitable_package pkg-config
   require_cmd cmake || suitable_package cmake
-  require_cmd cmake3 || suitable_package cmake3
+  require_cmd make || suitable_package make
 
   # -------------------------------------------------------------------------
   # debugging tools for development
@@ -1267,8 +1212,6 @@ packages() {
     require_cmd tar || suitable_package tar
     require_cmd curl || suitable_package curl
     require_cmd gzip || suitable_package gzip
-    require_cmd bison || suitable_package bison
-    require_cmd flex || suitable_package flex
   fi
 
   # -------------------------------------------------------------------------
@@ -1300,9 +1243,9 @@ packages() {
     suitable_package libuuid-dev
     suitable_package libmnl-dev
     suitable_package json-c-dev
-    suitable_package fts-dev
     suitable_package libyaml-dev
     suitable_package libsystemd-dev
+    suitable_package pcre2
   fi
 
   # -------------------------------------------------------------------------
@@ -1335,9 +1278,6 @@ packages() {
 
   if [ "${PACKAGES_NETDATA_PYTHON}" -ne 0 ]; then
     require_cmd python || suitable_package python
-
-    # suitable_package python-requests
-    # suitable_package python-pip
   fi
 
   # -------------------------------------------------------------------------
@@ -1345,9 +1285,6 @@ packages() {
 
   if [ "${PACKAGES_NETDATA_PYTHON3}" -ne 0 ]; then
     require_cmd python3 || suitable_package python3
-
-    # suitable_package python3-requests
-    # suitable_package python3-pip
   fi
 
   # -------------------------------------------------------------------------
